==> haskell-aeson-casing-0.2.0.0-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-LMJez1k5dOZEVSCnghVwu4
key:                  aeson-casing-0.2.0.0-LMJez1k5dOZEVSCnghVwu4
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  93a4c0567f1836ce26f07e467b25b3ef
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-LMJez1k5dOZEVSCnghVwu4
depends:              aeson-2.1.2.1-DotSWK7wQi51TFnSZ5tWn0 base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-casing-0.2.0.0-146-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-G7FzKPXqHmbGJfgq75FPbK
key:                  aeson-casing-0.2.0.0-G7FzKPXqHmbGJfgq75FPbK
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  da6365bc6e0544d21bca594765962d8b
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-G7FzKPXqHmbGJfgq75FPbK
depends:              aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
